@@ -3,6 +3,7 @@
 set -exo pipefail
 
 pushd "$1"
+TSS_VERSION=`git ls-remote --refs --tags https://github.com/tpm2-software/tpm2-tss.git | cut --delimiter='/' --fields=3 | tail --lines=1`
 
 if [ -z "$TPM2TSS_BRANCH" ]; then
     echo "TPM2TSS_BRANCH is unset, please specify TPM2TSS_BRANCH"
@@ -11,8 +12,13 @@ fi
 
 # Install tpm2-tss
 if [ ! -d tpm2-tss ]; then
-
-  git clone --depth=1 -b "${TPM2TSS_BRANCH}" "https://github.com/tpm2-software/tpm2-tss.git"
+  if [ -z "$GIT_FULL_CLONE" ]; then
+		echo "Doing shallow clone of tss"
+		git_extra_flags="--depth=1"
+	else
+		echo "Doing deep clone of tss"
+	fi
+  git clone $git_extra_flags -b "${TSS_VERSION}" "https://github.com/tpm2-software/tpm2-tss.git"
   pushd tpm2-tss
   ./bootstrap
   ./configure --enable-debug --disable-esys --disable-esapi --disable-fapi
