@@ -19,4 +19,7 @@ TSS2_TCTI_CONTEXT*    tcti_init_from_opts (test_opts_t        *options);
 TSS2_SYS_CONTEXT*     sapi_init_from_opts (test_opts_t        *options);
 void                  sapi_teardown_full  (TSS2_SYS_CONTEXT   *sapi_context);
 
+void                  tcti_free_from_opts (test_opts_t        *options,
+                                          TSS2_TCTI_CONTEXT **tcti_context);
+
 #endif /* CONTEXT_UTIL_H */
